Example project for `ska.contrib.django.ska` module.

See (https://github.com/barseghyanartur/ska/blob/stable/src/ska/contrib/django/ska/README.rst) for installation
and usage instructions.

See (https://github.com/barseghyanartur/ska/blob/stable/README.rst) for `ska` core installation and usage
instructions.
